[![Ruff](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json)](https://github.com/astral-sh/ruff)
[![Built with Spacemacs](https://raw.githubusercontent.com/syl20bnr/spacemacs/develop/assets/spacemacs-badge.svg)](https://develop.spacemacs.org)

To install the package run `pip install extrema`.

The documentation is in the
[docstrings](https://github.com/JohnADawson/extrema/blob/master/src/extrema.py).

# Copyright and License

Copyright (C) 2025 John Dawson

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License as published by the Free Software
Foundation, version 3.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program. If not, see <https://www.gnu.org/licenses/>.
